##  Changing Your Password
If you remember your current password, you can change it if needed. Follow these steps:
  1. When signed in, in the user profile menu, select My Settings.
  2. In the left-side panel, under My Settings, select Password.
  3. On the Password page, enter your current and new password, confirm the new password, then click Save.


Once you’ve changed your password, use the new password to sign in to SAP LeanIX.
